#!/usr/bin/perl -w

#
# $Id: fr.pm,v 1.1 2001/02/27 23:46:07 srl Exp $
#

package CGI::FormMagick::L10N::fr; # French
@ISA = qw(CGI::FormMagick::L10N);

%Lexicon = (

# basic strings used by FM

	"Next"
		=> "Suivant",
	"Previous"
		=> "Dernier",
	"Clear this form"
		=> "Effacer cette forme",
	"Start over again"
		=> "Recommencer",
	"Generated by"
		=> "Produit par",

# error message strings
# XXX most of these still need translating

	"Error"
		=> "Erreur",
);

1;

